summaryrefslogtreecommitdiff
path: root/gtk2_ardour/time_axis_view_item.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/time_axis_view_item.h')
-rw-r--r--gtk2_ardour/time_axis_view_item.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk2_ardour/time_axis_view_item.h b/gtk2_ardour/time_axis_view_item.h
index a099cb8380..c1d9d32c98 100644
--- a/gtk2_ardour/time_axis_view_item.h
+++ b/gtk2_ardour/time_axis_view_item.h
@@ -223,9 +223,9 @@ protected:
ArdourCanvas::Text* name_text;
ArdourCanvas::Rectangle* name_highlight;
- /* with these two values, if sample_handle_start == 0 then sample_handle_end will also be 0 */
- ArdourCanvas::Rectangle* sample_handle_start; ///< `sample' (fade) handle for the start of the item, or 0
- ArdourCanvas::Rectangle* sample_handle_end; ///< `sample' (fade) handle for the end of the item, or 0
+ /* with these two values, if frame_handle_start == 0 then frame_handle_end will also be 0 */
+ ArdourCanvas::Rectangle* frame_handle_start; ///< `sample' (fade) handle for the start of the item, or 0
+ ArdourCanvas::Rectangle* frame_handle_end; ///< `sample' (fade) handle for the end of the item, or 0
bool sample_handle_crossing (GdkEvent*, ArdourCanvas::Rectangle*);